AnyOf class abstract

Implementers

Constructors

AnyOf()

Properties

hashCode → int
The hash code for this object.
no setteroverride
isNull → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types → List<Type>
all available types to choose from
no setter
values → Map<int, Object?>
the actual values, accepts null
no setter
valueTypes → Set<Type>
all available types to choose from
no setter

Methods

isTX(int index) → bool
checks if values contain the input type index as a key
isType(Type t) → bool
checks if valueTypes contains the input type
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
returns value.toString()
override

Operators

operator ==(Object other) → bool
The equality operator.
override