AnyOfDynamic class

Inheritance

Constructors

AnyOfDynamic({required List<Type> types, required Map<int, Object?> values})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNull → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types → List<Type>
all available types to choose from
final
values → Map<int, Object?>
the actual values, accepts null
final
valueTypes → Set<Type>
all available types to choose from
no setterinherited

Methods

isTX(int index) → bool
checks if values contain the input type index as a key
inherited
isType(Type t) → bool
checks if valueTypes contains the input type
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
returns value.toString()
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited